@@ -251,9 +251,10 @@ void BrowserPage::render(const double &scaleFactor, const Dr::Rotation &rotation
 
             task.pixmapId = m_pixmapId;
 
-            task.rect = QRect(0, 0,
-                              static_cast<int>(boundingRect().width() * dApp->devicePixelRatio()),
-                              static_cast<int>(boundingRect().height() * dApp->devicePixelRatio()));
+            const qreal deviceRatio = dApp ? dApp->devicePixelRatio() : 1.0;
+            const int targetWidth = qMax(1, qRound(boundingRect().width() * deviceRatio));
+            const int targetHeight = qMax(1, qRound(boundingRect().height() * deviceRatio));
+            task.rect = QRect(0, 0, targetWidth, targetHeight);
 
             PageRenderThread::appendTask(task);
         } else {
@@ -266,9 +267,10 @@ void BrowserPage::render(const double &scaleFactor, const Dr::Rotation &rotation
 
             task.pixmapId = m_pixmapId;
 
-            task.rect = QRect(0, 0,
-                              static_cast<int>(boundingRect().width() * dApp->devicePixelRatio()),
-                              static_cast<int>(boundingRect().height() * dApp->devicePixelRatio()));
+            const qreal deviceRatio = dApp ? dApp->devicePixelRatio() : 1.0;
+            const int targetWidth = qMax(1, qRound(boundingRect().width() * deviceRatio));
+            const int targetHeight = qMax(1, qRound(boundingRect().height() * deviceRatio));
+            task.rect = QRect(0, 0, targetWidth, targetHeight);
 
             PageRenderThread::appendTask(task);
         }
@@ -1232,7 +1234,11 @@ BrowserWord *BrowserPage::getBrowserWord(const QPointF &point)
 bool BrowserPage::isBigDoc()
 {
     qCDebug(appLog) << "BrowserPage::isBigDoc() - Starting is big doc";
-    bool isBig = Dr::PDF == m_sheet->fileType() && boundingRect().width() > 1000 && boundingRect().height() > 1000;
+    bool supportedType = (Dr::PDF == m_sheet->fileType());
+#ifdef XPS_SUPPORT_ENABLED
+    supportedType = supportedType || (Dr::XPS == m_sheet->fileType());
+#endif
+    bool isBig = supportedType && boundingRect().width() > 1000 && boundingRect().height() > 1000;
     qCDebug(appLog) << "Checking if document is big:" << isBig;
     return isBig;
 }
