@@ -9,6 +9,7 @@
 #include "SideBarImageViewModel.h"
 #include "SearchResDelegate.h"
 #include "Model.h"
+#include "ddlog.h"
 
 #include <DLabel>
 #include <QDebug>
@@ -21,18 +22,18 @@ const int LEFTMINHEIGHT = 80;
 SearchResWidget::SearchResWidget(DocSheet *sheet, DWidget *parent)
     : BaseWidget(parent), m_sheet(sheet)
 {
-    qDebug() << "SearchResWidget created for document:" << (sheet ? sheet->filePath() : "null");
+    qCDebug(appLog) << "SearchResWidget created for document:" << (sheet ? sheet->filePath() : "null");
     initWidget();
 }
 
 SearchResWidget::~SearchResWidget()
 {
-    qDebug() << "SearchResWidget destroyed";
+    qCDebug(appLog) << "SearchResWidget destroyed";
 }
 
 void SearchResWidget::initWidget()
 {
-    qDebug() << "Initializing SearchResWidget UI";
+    qCDebug(appLog) << "Initializing SearchResWidget UI";
     m_stackLayout = new QStackedLayout;
     m_stackLayout->setContentsMargins(0, 8, 0, 0);
     m_stackLayout->setSpacing(0);
@@ -56,7 +57,7 @@ void SearchResWidget::initWidget()
 
 void SearchResWidget::handleSearchResultComming(const deepin_reader::SearchResult &search)
 {
-    qDebug() << "Processing search result for page:" << search.page;
+    qCDebug(appLog) << "Processing search result for page:" << search.page;
     QString strText;
     for (const auto &section : search.sections) {
         for (const auto &line : section) {
@@ -70,12 +71,12 @@ void SearchResWidget::handleSearchResultComming(const deepin_reader::SearchResul
 int  SearchResWidget::handleFindFinished()
 {
     int searchCount = m_pImageListView->model()->rowCount();
-    qDebug() << "Search finished, found" << searchCount << "results";
+    qCDebug(appLog) << "Search finished, found" << searchCount << "results";
     if (searchCount <= 0) {
-        qDebug() << "Showing no results tip";
+        qCDebug(appLog) << "Showing no results tip";
         m_stackLayout->setCurrentIndex(TIPS_INDEX);
     } else {
-        qDebug() << "Showing search results";
+        qCDebug(appLog) << "Showing search results";
         m_stackLayout->setCurrentIndex(SEARCH_INDEX);
     }
     return searchCount;
@@ -83,21 +84,26 @@ int  SearchResWidget::handleFindFinished()
 
 void SearchResWidget::clearFindResult()
 {
+    qCDebug(appLog) << "SearchResWidget::clearFindResult start";
     m_searchKey.clear();
     m_stackLayout->setCurrentIndex(SEARCH_INDEX);
     m_pImageListView->getImageModel()->resetData();
+    qCDebug(appLog) << "SearchResWidget::clearFindResult end";
 }
 
 void SearchResWidget::searchKey(const QString &searchKey)
 {
-    qDebug() << "Setting search key:" << searchKey;
+    qCDebug(appLog) << "Setting search key:" << searchKey;
     m_searchKey = searchKey;
 }
 
 void SearchResWidget::addSearchsItem(const int &pageIndex, const QString &text, const int &resultNum)
 {
-    if (nullptr == m_sheet && !text.contains(m_searchKey))
+    qCDebug(appLog) << "SearchResWidget::addSearchsItem start";
+    if (nullptr == m_sheet && !text.contains(m_searchKey)) {
+        qCDebug(appLog) << "Invalid sheet or text does not contain search key";
         return;
+    }
 
     ImagePageInfo_t tImagePageInfo;
     tImagePageInfo.pageIndex = pageIndex;
@@ -105,13 +111,16 @@ void SearchResWidget::addSearchsItem(const int &pageIndex, const QString &text,
     tImagePageInfo.strSearchcount = tr("%1 items found").arg(resultNum);
     m_pImageListView->getImageModel()->insertPageIndex(tImagePageInfo);
 
-    if (m_stackLayout->currentIndex() != SEARCH_INDEX)
+    if (m_stackLayout->currentIndex() != SEARCH_INDEX) {
+        qCDebug(appLog) << "Setting current index to SEARCH_INDEX";
         m_stackLayout->setCurrentIndex(SEARCH_INDEX);
+    }
+    qCDebug(appLog) << "SearchResWidget::addSearchsItem end";
 }
 
 void SearchResWidget::adaptWindowSize(const double &scale)
 {
-    qDebug() << "Adapting window size with scale:" << scale;
+    qCDebug(appLog) << "Adapting window size with scale:" << scale;
     const QModelIndex &curModelIndex = m_pImageListView->currentIndex();
     m_pImageListView->setProperty("adaptScale", scale);
     m_pImageListView->setItemSize(QSize(static_cast<int>(LEFTMINWIDTH * scale), LEFTMINHEIGHT));
