@@ -13,6 +13,7 @@
 #include "Model.h"
 #include "MsgHeader.h"
 #include "Utils.h"
+#include "ddlog.h"
 
 #include <DPushButton>
 #include <DGuiApplicationHelper>
@@ -29,19 +30,19 @@ SheetSidebar::SheetSidebar(DocSheet *parent, PreviewWidgesFlags widgesFlag)
     , m_sheet(parent)
     , m_widgetsFlag(widgesFlag | PREVIEW_SEARCH)
 {
-    qDebug() << "SheetSidebar created with flags:" << widgesFlag;
+    qCDebug(appLog) << "SheetSidebar created with flags:" << widgesFlag;
     initWidget();
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &SheetSidebar::onUpdateWidgetTheme);
 }
 
 SheetSidebar::~SheetSidebar()
 {
-    qDebug() << "SheetSidebar destroyed";
+    qCDebug(appLog) << "SheetSidebar destroyed";
 }
 
 void SheetSidebar::initWidget()
 {
-    qDebug() << "Initializing SheetSidebar UI";
+    qCDebug(appLog) << "Initializing SheetSidebar UI";
     m_scale           = 1.0;
     m_bOldVisible     = false;
     m_bOpenDocOpenSuccess = false;
@@ -68,6 +69,7 @@ void SheetSidebar::initWidget()
     QList<QWidget *> tabWidgetlst;
 
     if (m_widgetsFlag.testFlag(PREVIEW_THUMBNAIL)) {
+        qCDebug(appLog) << "Creating thumbnail widget";
         m_thumbnailWidget = new ThumbnailWidget(m_sheet, this);
         int index = m_stackLayout->addWidget(m_thumbnailWidget);
         DToolButton *btn = createBtn(tr("Thumbnails"), "thumbnail");
@@ -83,6 +85,7 @@ void SheetSidebar::initWidget()
     }
 
     if (m_widgetsFlag.testFlag(PREVIEW_CATALOG)) {
+        qCDebug(appLog) << "Creating catalog widget";
         m_catalogWidget = new CatalogWidget(m_sheet, this);
         int index = m_stackLayout->addWidget(m_catalogWidget);
         DToolButton *btn = createBtn(tr("Catalog"), "catalog");
@@ -96,6 +99,7 @@ void SheetSidebar::initWidget()
     }
 
     if (m_widgetsFlag.testFlag(PREVIEW_BOOKMARK)) {
+        qCDebug(appLog) << "Creating bookmark widget";
         m_bookmarkWidget = new BookMarkWidget(m_sheet, this);
         int index = m_stackLayout->addWidget(m_bookmarkWidget);
         DToolButton *btn = createBtn(tr("Bookmarks"), "bookmark");
@@ -111,6 +115,7 @@ void SheetSidebar::initWidget()
     }
 
     if (m_widgetsFlag.testFlag(PREVIEW_NOTE)) {
+        qCDebug(appLog) << "Creating notes widget";
         m_notesWidget = new NotesWidget(m_sheet, this);
         int index = m_stackLayout->addWidget(m_notesWidget);
         DToolButton *btn = createBtn(tr("Annotations"), "annotation");
@@ -130,6 +135,7 @@ void SheetSidebar::initWidget()
     if (item) delete item;
 
     if (m_widgetsFlag.testFlag(PREVIEW_SEARCH)) {
+        qCDebug(appLog) << "Creating search widget";
         m_searchWidget = new SearchResWidget(m_sheet, this);
         m_searchId = m_stackLayout->addWidget(m_searchWidget);
         DToolButton *btn = createBtn("Search", "search");
@@ -192,8 +198,9 @@ void SheetSidebar::initWidget()
 
 void SheetSidebar::onBtnClicked(int index)
 {
+    qCDebug(appLog) << "Button clicked at index:" << index;
     if (!m_btnGroupMap.contains(index)) {
-        qWarning() << "Invalid button index:" << index;
+        qCWarning(appLog) << "Invalid button index:" << index;
         return;
     }
 
@@ -208,56 +215,89 @@ void SheetSidebar::onBtnClicked(int index)
         m_sheet->m_operation.sidebarIndex = index;
     }
     onHandleOpenSuccessDelay();
+    qCDebug(appLog) << "SheetSidebar::onBtnClicked end";
 }
 
 void SheetSidebar::setBookMark(int index, int state)
 {
-    if (m_bookmarkWidget) m_bookmarkWidget->handleBookMark(index, state);
-    if (m_thumbnailWidget) m_thumbnailWidget->setBookMarkState(index, state);
+    qCDebug(appLog) << "SheetSidebar::setBookMark start";
+    if (m_bookmarkWidget) {
+        qCDebug(appLog) << "Handling bookmark for index:" << index << "state:" << state;
+        m_bookmarkWidget->handleBookMark(index, state);
+    }
+    if (m_thumbnailWidget) {
+        qCDebug(appLog) << "Setting bookmark state for thumbnail widget";
+        m_thumbnailWidget->setBookMarkState(index, state);
+    }
+    qCDebug(appLog) << "SheetSidebar::setBookMark end";
 }
 
 void SheetSidebar::setCurrentPage(int page)
 {
-    if (m_thumbnailWidget) m_thumbnailWidget->handlePage(page - 1);
-    if (m_bookmarkWidget) m_bookmarkWidget->handlePage(page - 1);
-    if (m_catalogWidget) m_catalogWidget->handlePage(page - 1);
+    qCDebug(appLog) << "SheetSidebar::setCurrentPage start - page:" << page;
+    if (m_thumbnailWidget) {
+        qCDebug(appLog) << "Setting page for thumbnail widget";
+        m_thumbnailWidget->handlePage(page - 1);
+    }
+    if (m_bookmarkWidget) {
+        qCDebug(appLog) << "Setting page for bookmark widget";
+        m_bookmarkWidget->handlePage(page - 1);
+    }
+    if (m_catalogWidget) {
+        qCDebug(appLog) << "Setting page for catalog widget";
+        m_catalogWidget->handlePage(page - 1);
+    }
+    qCDebug(appLog) << "SheetSidebar::setCurrentPage end";
 }
 
 void SheetSidebar::handleOpenSuccess()
 {
+    qCDebug(appLog) << "SheetSidebar::handleOpenSuccess start";
     m_bOpenDocOpenSuccess = true;
     this->setVisible(m_sheet->operation().sidebarVisible);
     int nId = qBound(0, m_sheet->operation().sidebarIndex, m_stackLayout->count() - 2);
     onBtnClicked(nId);
+    qCDebug(appLog) << "SheetSidebar::handleOpenSuccess end";
 }
 
 void SheetSidebar::onHandleOpenSuccessDelay()
 {
+    qCDebug(appLog) << "SheetSidebar::onHandleOpenSuccessDelay start";
     if (m_bOpenDocOpenSuccess) {
+        qCDebug(appLog) << "Document opened successfully, setting single shot timer";
         QTimer::singleShot(100, this, SLOT(onHandWidgetDocOpenSuccess()));
     }
+    qCDebug(appLog) << "SheetSidebar::onHandleOpenSuccessDelay end";
 }
 
 void SheetSidebar::onHandWidgetDocOpenSuccess()
 {
-    if (!this->isVisible())
+    qCDebug(appLog) << "SheetSidebar::onHandWidgetDocOpenSuccess start";
+    if (!this->isVisible()) {
+        qCDebug(appLog) << "Widget not visible, returning";
         return;
+    }
 
     QWidget *curWidget = m_stackLayout->currentWidget();
     if (curWidget == m_thumbnailWidget) {
+        qCDebug(appLog) << "Handling open success for thumbnail widget";
         m_thumbnailWidget->handleOpenSuccess();
     } else if (curWidget == m_catalogWidget) {
+        qCDebug(appLog) << "Handling open success for catalog widget";
         m_catalogWidget->handleOpenSuccess();
     } else if (curWidget == m_bookmarkWidget) {
+        qCDebug(appLog) << "Handling open success for bookmark widget";
         m_bookmarkWidget->handleOpenSuccess();
     } else if (curWidget == m_notesWidget) {
+        qCDebug(appLog) << "Handling open success for notes widget";
         m_notesWidget->handleOpenSuccess();
     }
+    qCDebug(appLog) << "SheetSidebar::onHandWidgetDocOpenSuccess end";
 }
 
 void SheetSidebar::handleSearchStart(const QString &text)
 {
-    qDebug() << "Starting search for:" << text;
+    qCDebug(appLog) << "Starting search for:" << text;
     for (auto iter = m_btnGroupMap.begin(); iter != m_btnGroupMap.end(); iter++) {
         iter.value()->setEnabled(false);
     }
@@ -266,11 +306,12 @@ void SheetSidebar::handleSearchStart(const QString &text)
     m_searchWidget->searchKey(text);
     onBtnClicked(m_searchId);
     this->setVisible(true);
-    qDebug() << "Search UI activated";
+    qCDebug(appLog) << "Search UI activated";
 }
 
 void SheetSidebar::handleSearchStop()
 {
+    qCDebug(appLog) << "SheetSidebar::handleSearchStop start";
     for (auto iter = m_btnGroupMap.begin(); iter != m_btnGroupMap.end(); iter++) {
         iter.value()->setEnabled(true);
     }
@@ -279,34 +320,42 @@ void SheetSidebar::handleSearchStop()
     onBtnClicked(nId);
     this->setVisible(m_sheet->operation().sidebarVisible);
     m_searchWidget->clearFindResult();
+    qCDebug(appLog) << "SheetSidebar::handleSearchStop end";
 }
 
 void SheetSidebar::handleSearchResultComming(const deepin_reader::SearchResult &res)
 {
+    qCDebug(appLog) << "SheetSidebar::handleSearchResultComming start";
     m_searchWidget->handleSearchResultComming(res);
 }
 
 int SheetSidebar::handleFindFinished()
 {
+    qCDebug(appLog) << "SheetSidebar::handleFindFinished start";
     return m_searchWidget->handleFindFinished();
 }
 
 void SheetSidebar::handleRotate()
 {
+    qCDebug(appLog) << "SheetSidebar::handleRotate start";
     if (m_thumbnailWidget)
         m_thumbnailWidget->handleRotate();
+    qCDebug(appLog) << "SheetSidebar::handleRotate end";
 }
 
 void SheetSidebar::handleAnntationMsg(const int &msg, int index, deepin_reader::Annotation *anno)
 {
+    qCDebug(appLog) << "SheetSidebar::handleAnntationMsg start";
     if (m_notesWidget)
         m_notesWidget->handleAnntationMsg(msg, anno);
 
     Q_UNUSED(index);
+    qCDebug(appLog) << "SheetSidebar::handleAnntationMsg end";
 }
 
 DToolButton *SheetSidebar::createBtn(const QString &btnName, const QString &objName)
 {
+    qCDebug(appLog) << "Creating button:" << btnName;
     int tW = 36;
     auto btn = new DToolButton(this);
     btn->setToolTip(btnName);
@@ -318,29 +367,33 @@ DToolButton *SheetSidebar::createBtn(const QString &btnName, const QString &objN
     if ("search" != objName) {
         btn->setFocusPolicy(Qt::TabFocus);
     }
+    qCDebug(appLog) << "Button created:" << btnName;
     return btn;
 }
 
 void SheetSidebar::resizeEvent(QResizeEvent *event)
 {
+    // qCDebug(appLog) << "SheetSidebar::resizeEvent start - size:" << event->size();
     qreal scale = event->size().width() * 1.0 / LEFTMINWIDTH;
     adaptWindowSize(scale);
     BaseWidget::resizeEvent(event);
+    // qCDebug(appLog) << "SheetSidebar::resizeEvent end";
 }
 
 void SheetSidebar::adaptWindowSize(const double &scale)
 {
-    qDebug() << "Adapting window size with scale:" << scale;
+    qCDebug(appLog) << "Adapting window size with scale:" << scale;
     m_scale = scale;
     BaseWidget *curWidget = dynamic_cast<BaseWidget *>(m_stackLayout->currentWidget());
     if (curWidget) {
-        qDebug() << "Adapting widget:" << curWidget->metaObject()->className();
+        qCDebug(appLog) << "Adapting widget:" << curWidget->metaObject()->className();
         curWidget->adaptWindowSize(scale);
     }
 }
 
 void SheetSidebar::keyPressEvent(QKeyEvent *event)
 {
+    // qCDebug(appLog) << "SheetSidebar::keyPressEvent start - key:" << event->key();
     QStringList pFilterList = QStringList() << Dr::key_pgUp << Dr::key_pgDown
                               << Dr::key_down << Dr::key_up
                               << Dr::key_left << Dr::key_right
@@ -349,20 +402,25 @@ void SheetSidebar::keyPressEvent(QKeyEvent *event)
     QString key = Utils::getKeyshortcut(event);
 
     if (pFilterList.contains(key)) {
+        // qCDebug(appLog) << "Processing filtered key:" << key;
         dealWithPressKey(key);
     }
 
     BaseWidget::keyPressEvent(event);
+    // qCDebug(appLog) << "SheetSidebar::keyPressEvent end";
 }
 
 void SheetSidebar::showEvent(QShowEvent *event)
 {
+    // qCDebug(appLog) << "SheetSidebar::showEvent start";
     BaseWidget::showEvent(event);
     onHandleOpenSuccessDelay();
+    // qCDebug(appLog) << "SheetSidebar::showEvent end";
 }
 
 void SheetSidebar::showMenu()
 {
+    qCDebug(appLog) << "Showing menu";
     DToolButton *bookmarkbtn = this->findChild<DToolButton *>("bookmark");
     if (m_bookmarkWidget && bookmarkbtn && bookmarkbtn->isChecked()) {
         m_bookmarkWidget->showMenu();
@@ -371,10 +429,12 @@ void SheetSidebar::showMenu()
     if (m_notesWidget && annotationbtn && annotationbtn->isChecked()) {
         m_notesWidget->showMenu();
     }
+    qCDebug(appLog) << "Menu shown";
 }
 
 void SheetSidebar::dealWithPressKey(const QString &sKey)
 {
+    qCDebug(appLog) << "Dealing with press key:" << sKey;
     if (sKey == Dr::key_up || sKey == Dr::key_left) {
         onJumpToPrevPage();
     } else if (sKey == Dr::key_pgUp) {
@@ -386,105 +446,141 @@ void SheetSidebar::dealWithPressKey(const QString &sKey)
     } else if (sKey == Dr::key_delete) {
         deleteItemByKey();
     }
+    qCDebug(appLog) << "Dealing with press key end";
 }
 
 void SheetSidebar::onJumpToPrevPage()
 {
+    qCDebug(appLog) << "Jumping to previous page";
     QWidget *curWidget = m_stackLayout->currentWidget();
-    qDebug() << "Jumping to previous page in widget:" << (curWidget ? curWidget->metaObject()->className() : "null");
+    qCDebug(appLog) << "Jumping to previous page in widget:" << (curWidget ? curWidget->metaObject()->className() : "null");
     if (curWidget == m_thumbnailWidget) {
+        qCDebug(appLog) << "Jumping to previous page in thumbnail widget";
         m_thumbnailWidget->prevPage();
     }  else if (curWidget == m_bookmarkWidget) {
+        qCDebug(appLog) << "Jumping to previous page in bookmark widget";
         m_bookmarkWidget->prevPage();
     } else if (curWidget == m_notesWidget) {
+        qCDebug(appLog) << "Jumping to previous page in notes widget";
         m_notesWidget->prevPage();
     } else if (curWidget == m_catalogWidget) {
+        qCDebug(appLog) << "Jumping to previous page in catalog widget";
         m_catalogWidget->prevPage();
     }
+    qCDebug(appLog) << "Jumping to previous page end";
 }
 
 void SheetSidebar::onJumpToPageUp()
 {
+    qCDebug(appLog) << "Jumping to page up";
     QWidget *curWidget = m_stackLayout->currentWidget();
     if (curWidget == m_thumbnailWidget) {
+        qCDebug(appLog) << "Jumping to page up in thumbnail widget";
         m_thumbnailWidget->pageUp();
     } else if (curWidget == m_bookmarkWidget) {
+        qCDebug(appLog) << "Jumping to page up in bookmark widget";
         m_bookmarkWidget->pageUp();
     } else if (curWidget == m_notesWidget) {
+        qCDebug(appLog) << "Jumping to page up in notes widget";
         m_notesWidget->pageUp();
     } else if (curWidget == m_catalogWidget) {
+        qCDebug(appLog) << "Jumping to page up in catalog widget";
         m_catalogWidget->pageUp();
     }
+    qCDebug(appLog) << "Jumping to page up end";
 }
 
 void SheetSidebar::onJumpToNextPage()
 {
+    qCDebug(appLog) << "Jumping to next page";
     QWidget *curWidget = m_stackLayout->currentWidget();
     if (curWidget == m_thumbnailWidget) {
+        qCDebug(appLog) << "Jumping to next page in thumbnail widget";
         m_thumbnailWidget->nextPage();
     }  else if (curWidget == m_bookmarkWidget) {
+        qCDebug(appLog) << "Jumping to next page in bookmark widget";
         m_bookmarkWidget->nextPage();
     } else if (curWidget == m_notesWidget) {
+        qCDebug(appLog) << "Jumping to next page in notes widget";
         m_notesWidget->nextPage();
     } else if (curWidget == m_catalogWidget) {
+        qCDebug(appLog) << "Jumping to next page in catalog widget";
         m_catalogWidget->nextPage();
     }
+    qCDebug(appLog) << "Jumping to next page end";
 }
 
 void SheetSidebar::onJumpToPageDown()
 {
+    qCDebug(appLog) << "Jumping to page down";
     QWidget *curWidget = m_stackLayout->currentWidget();
     if (curWidget == m_thumbnailWidget) {
+        qCDebug(appLog) << "Jumping to page down in thumbnail widget";
         m_thumbnailWidget->pageDown();
     } else if (curWidget == m_bookmarkWidget) {
+        qCDebug(appLog) << "Jumping to page down in bookmark widget";
         m_bookmarkWidget->pageDown();
     } else if (curWidget == m_notesWidget) {
+        qCDebug(appLog) << "Jumping to page down in notes widget";
         m_notesWidget->pageDown();
     } else if (curWidget == m_catalogWidget) {
+        qCDebug(appLog) << "Jumping to page down in catalog widget";
         m_catalogWidget->pageDown();
     }
+    qCDebug(appLog) << "Jumping to page down end";
 }
 
 void SheetSidebar::deleteItemByKey()
 {
+    qCDebug(appLog) << "Deleting item by key";
     QWidget *widget = m_stackLayout->currentWidget();
     if (widget == m_bookmarkWidget) {
+        qCDebug(appLog) << "Deleting item by key in bookmark widget";
         m_bookmarkWidget->deleteItemByKey();
     } else if (widget == m_notesWidget) {
+        qCDebug(appLog) << "Deleting item by key in notes widget";
         m_notesWidget->deleteItemByKey();
     }
+    qCDebug(appLog) << "Deleting item by key end";
 }
 
 bool SheetSidebar::event(QEvent *event)
 {
+    // qCDebug(appLog) << "SheetSidebar::event start - type:" << event->type();
     if (event->type() == QEvent::KeyPress) {
         QKeyEvent *key_event = static_cast<QKeyEvent *>(event);
         if (key_event->key() == Qt::Key_Menu && !key_event->isAutoRepeat()) {
+            // qCDebug(appLog) << "Key_Menu pressed, showing menu";
             showMenu();
         }
         if (key_event->key() == Qt::Key_M && (key_event->modifiers() & Qt::AltModifier) && !key_event->isAutoRepeat()) {
+            // qCDebug(appLog) << "Alt+M pressed, showing menu";
             showMenu();
         }
     }
 
+    // qCDebug(appLog) << "SheetSidebar::event end";
     return BaseWidget::event(event);
 }
 
 void SheetSidebar::onUpdateWidgetTheme()
 {
-    qDebug() << "Updating widget theme";
+    qCDebug(appLog) << "Updating widget theme";
     updateWidgetTheme();
     for (auto iter = m_btnGroupMap.begin(); iter != m_btnGroupMap.end(); iter++) {
         const QString &objName = iter.value()->objectName();
         const QIcon &icon = QIcon::fromTheme(QString("dr_") + objName);
         iter.value()->setIcon(icon);
-        qDebug() << "Updated icon for button:" << objName;
+        // qCDebug(appLog) << "Updated icon for button:" << objName;
     }
 }
 
 void SheetSidebar::changeResetModelData()
 {
+    // qCDebug(appLog) << "Changing reset model data";
     if (m_notesWidget) {
+        // qCDebug(appLog) << "Changing reset model data in notes widget";
         m_notesWidget->changeResetModelData();
     }
+    // qCDebug(appLog) << "Changing reset model data end";
 }
