@@ -12,6 +12,8 @@
 #include <QSet>
 #include <QReadWriteLock>
 #include <QThread>
+#include <QSize>
+#include <QRectF>
 
 class SheetSidebar;
 class SlideWidget;
@@ -810,6 +812,7 @@ private slots:
     void onExtractPassword(const QString &password);
 
 private:
+    QSize calculatePrintTargetSize(int pageIndex, const QPrinter &printer, const QRectF &pageRect) const;
     /**
      * @brief setAlive
      * 设置当前sheet是否存活
@@ -873,6 +876,11 @@ public:
          */
         QImage getImage(DocSheet *doc, int index, int width, int height);
 
+        /**
+         * @brief getImageForPrint 打印专用图像获取接口
+         */
+        QImage getImageForPrint(DocSheet *doc, int index, const QSize &targetSize);
+
     protected:
         void paintEvent(QPaintEvent */*event*/) override;
 
