@@ -6,6 +6,8 @@
 #include "TransparentTextEdit.h"
 #include "Application.h"
 #include "MsgHeader.h"
+#include "ddlog.h"
+
 #include <QDebug>
 
 #include <DFontSizeManager>
@@ -20,7 +22,7 @@
 TransparentTextEdit::TransparentTextEdit(DWidget *parent)
     : QTextEdit(parent)
 {
-    qDebug() << "TransparentTextEdit created, parent:" << parent;
+    qCDebug(appLog) << "TransparentTextEdit created, parent:" << parent;
     this->setObjectName("TransparentTextEdit");
 
     this->setAcceptRichText(false);
@@ -45,16 +47,18 @@ TransparentTextEdit::TransparentTextEdit(DWidget *parent)
     this->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
     connect(this, SIGNAL(textChanged()), this, SLOT(slotTextEditMaxContantNum()));
+    qCDebug(appLog) << "TransparentTextEdit initialized";
 }
 
 void TransparentTextEdit::slotTextEditMaxContantNum()
 {
-    qDebug() << "Checking text content length, max:" << m_nMaxContantLen;
+    qCDebug(appLog) << "Checking text content length, max:" << m_nMaxContantLen;
     QString textContent = this->toPlainText();
 
     int length = textContent.count();
 
     if (length > m_nMaxContantLen) {
+        qCDebug(appLog) << "Text length exceeds limit, trimming content";
         int position = this->textCursor().position();
 
         QTextCursor textCursor = this->textCursor();
@@ -69,10 +73,12 @@ void TransparentTextEdit::slotTextEditMaxContantNum()
 
         sigNeedShowTips(tr("Input limit reached"), 1);
     }
+    qCDebug(appLog) << "TransparentTextEdit::slotTextEditMaxContantNum end";
 }
 
 void TransparentTextEdit::paintEvent(QPaintEvent *event)
 {
+    // qCDebug(appLog) << "TransparentTextEdit::paintEvent start";
     QTextEdit::paintEvent(event);
 
     QPainter painter(this->viewport());
@@ -108,6 +114,7 @@ void TransparentTextEdit::paintEvent(QPaintEvent *event)
     }
 
     if (this->verticalScrollBar()->maximum() - this->verticalScrollBar()->value() < maxLineHeight) {
+        // qCDebug(appLog) << "Drawing bottom line";
         pen.setWidth(maxLineHeight);
 
         painter.setPen(pen);
@@ -116,22 +123,25 @@ void TransparentTextEdit::paintEvent(QPaintEvent *event)
 
         painter.drawLine(QPointF(2.0, curh), QPointF(this->viewport()->width() * 1.0 - 4.0, curh));
     }
+    // qCDebug(appLog) << "TransparentTextEdit::paintEvent end";
 }
 
 void TransparentTextEdit::insertFromMimeData(const QMimeData *source)
 {
-    qDebug() << "Inserting from mime data, has text:" << !source->text().isEmpty();
+    qCDebug(appLog) << "Inserting from mime data, has text:" << !source->text().isEmpty();
     if (!source->text().isEmpty())
         this->insertPlainText(source->text());
 }
 
 void TransparentTextEdit::keyPressEvent(QKeyEvent *keyEvent)
 {
-    qDebug() << "Key pressed:" << keyEvent->key() << "modifiers:" << keyEvent->modifiers();
+    // qCDebug(appLog) << "Key pressed:" << keyEvent->key() << "modifiers:" << keyEvent->modifiers();
     if (keyEvent->key() == Qt::Key_M && (keyEvent->modifiers() & Qt::AltModifier) && !keyEvent->isAutoRepeat()) {
+        // qCDebug(appLog) << "Alt+M pressed, showing context menu";
         QMenu *menu =  this->createStandardContextMenu();
 
         if (menu) {
+            // qCDebug(appLog) << "Showing context menu";
             menu->exec(this->cursor().pos());
             delete  menu;
             menu = nullptr;
@@ -140,12 +150,14 @@ void TransparentTextEdit::keyPressEvent(QKeyEvent *keyEvent)
     }
 
     QTextEdit::keyPressEvent(keyEvent);
+    // qCDebug(appLog) << "TransparentTextEdit::keyPressEvent end";
 }
 
 void TransparentTextEdit::focusOutEvent(QFocusEvent *event)
 {
-    qDebug() << "Focus out event, reason:" << event->reason();
+    // qCDebug(appLog) << "Focus out event, reason:" << event->reason();
     QTextEdit::focusOutEvent(event);
 
     Q_EMIT sigCloseNoteWidget();
+    // qCDebug(appLog) << "TransparentTextEdit::focusOutEvent end";
 }
